#!/usr/bin/python

Version = '0.3.4'

"""
Rigid Tapping G-Code Generator
Copyright (C) <2013>  <John Thornton>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

e-mail me any suggestions to "bjt 128 at gmail dot com"
If you make money using this software
you must donate $20 USD to a local food bank
or the food police will get you! Think of others from time to time...

To make it a menu item in Ubuntu use the Alacarte Menu Editor and add 
the command python YourPathToThisFile/face.py
make sure you have made the file execuatble by right
clicking and selecting properties then Permissions and Execute

To use with EMC2 see the instructions at: 
http://wiki.linuxcnc.org/cgi-bin/emcinfo.pl?Simple_EMC_G-Code_Generators

Version 0.1.0 added metric drill sizes but dictionary needs converting
Version 0.2.0 added support for G83
Version 0.3.0 added F1 key binding to the help screen and changed the Tkinter import
  add warning about metric units

"""
#from Tkinter import *
import Tkinter as tk
from math import *
import tkMessageBox
import os

IN_AXIS = os.environ.has_key("AXIS_PROGRESS_BAR")

#class Application(Frame):
class Application(tk.Frame):
  def __init__(self, master=None):
    tk.Frame.__init__(self, master)
    self.grid()
    self.master.bind("<F1>", self.HelpInfo)
    self.createMenu()
    self.createWidgets()

  def createMenu(self):
      #Create the Menu base
      self.menu = tk.Menu(self)
      #Add the Menu
      self.master.config(menu=self.menu)
      #Create our File menu
      self.FileMenu = tk.Menu(self.menu)
      #Add our Menu to the Base Menu
      self.menu.add_cascade(label='File', menu=self.FileMenu)
      #Add items to the menu
      self.FileMenu.add_command(label='Cancel', command=self.quit)
      self.EditMenu = tk.Menu(self.menu)
      self.menu.add_cascade(label='Edit', menu=self.EditMenu)
      self.HelpMenu = tk.Menu(self.menu)
      self.menu.add_cascade(label='Help', menu=self.HelpMenu)
      self.HelpMenu.add_command(label='Help Info', command=self.HelpInfo)
      self.HelpMenu.add_command(label='About', command=self.HelpAbout)

  def createWidgets(self):
      self.title = tk.Label(self, text='Rigid Tapping G-Code Generator')
      self.title.grid(row=0, column=0, columnspan=10)

      self.cl1 = tk.Label(self, text=' NF Taps ')
      self.cl1.grid(row=1, column=0)
      self.SHCS1=[('#6-40  ',1),('#8-36  ',2),('#10-32 ',3),('#12-28 ',4),('1/4-28 ',5),
      ('5/16-24',6),('3/8-24 ',7),('7/16-20',8),('1/2-20 ',9),('9/16-18',10),('5/8-18 ',11)]
      self.var1 = tk.IntVar()
      for text, value in self.SHCS1:
          self.rb1 = tk.Radiobutton(self, text=text, value=value, variable=self.var1,
          font="monospace 10")
          self.rb1.grid(column=0,row=value+1)
          self.rb1.bind("<ButtonRelease-1>", self.rb1event)
      self.var1.set(0)
      
      self.cl2 = tk.Label(self, text=' NC Taps ')
      self.cl2.grid(row=1, column=1)
      self.SHCS2=[('#6-32  ',1),('#8-32  ',2),('#10-24 ',3),('#12-24 ',4),('1/4-20 ',5),
      ('5/16-18',6),('3/8-16 ',7),('7/16-14',8),('1/2-13 ',9),('9/16-12',10),
      ('5/8-11 ',11)]
      self.var2 = tk.IntVar()
      for text, value in self.SHCS2:
          self.rb2=tk.Radiobutton(self, text=text, value=value, variable=self.var2,
          font="monospace 10")
          self.rb2.grid(column=1,row=value+1)
          self.rb2.bind("<ButtonRelease-1>", self.rb2event)

      self.cl3 = tk.Label(self, text=' Metric Taps ')
      self.cl3.grid(row=1, column=2)
      self.SHCS3=[('M3-0.5  ',1),('M4-0.7  ',2),('M5-0.8  ',3),('M6-1.0  ',4),('M8-1.25 ',5),
      ('M10-1.5 ',6),('M12-1.75',7),('M14-2.0 ',8),('M16-2.0 ',9)]
      self.var3 = tk.IntVar()
      for text, value in self.SHCS3:
          self.rb3=tk.Radiobutton(self, text=text, value=value, variable=self.var3,
          font="monospace 10")
          self.rb3.grid(column=2,row=value+1)
          self.rb3.bind("<ButtonRelease-1>", self.rb3event)

      self.st0 = tk.Label(self, text='Tap')
      self.st0.grid(row=13, column=0)
      self.TapSizeVar = tk.StringVar()
      self.TapSize = tk.Entry(self, width=10, textvariable=self.TapSizeVar)
      self.TapSize.grid(row=14, column=0)
      self.TapSize.bind("<Return>", self.TabToNext)
      self.TapSize.bind("<KP_Enter>", self.TabToNext)

      self.st1 = tk.Label(self, text='Tap Drill')
      self.st1.grid(row=13, column=1)
      self.TapDrill = tk.StringVar()
      self.HoleDiameterE = tk.Entry(self, width=10, textvariable=self.TapDrill)
      self.HoleDiameterE.grid(row=14, column=1)
      self.HoleDiameterE.bind("<Return>", self.TabToNext)
      self.HoleDiameterE.bind("<KP_Enter>", self.TabToNext)

      self.st2 = tk.Label(self, text='Diameter')
      self.st2.grid(row=13, column=2)
      self.HoleDepthVar = tk.StringVar()
      self.HoleDepthE = tk.Entry(self, width=10, textvariable=self.HoleDepthVar)
      self.HoleDepthE.grid(row=14, column=2)
      self.HoleDepthE.bind("<Return>", self.TabToNext)
      self.HoleDepthE.bind("<KP_Enter>", self.TabToNext)

      self.st3 = tk.Label(self, text='Clear Height Z')
      self.st3.grid(row=15, column=0)
      self.ClearHeightVar = tk.StringVar()
      self.ClearHeightE = tk.Entry(self, width=10, textvariable=self.ClearHeightVar)
      self.ClearHeightE.grid(row=16, column=0)
      self.ClearHeightVar.set('0.2500')
      self.ClearHeightE.bind("<Return>", self.TabToNext)
      self.ClearHeightE.bind("<KP_Enter>", self.TabToNext)

      self.st4 = tk.Label(self, text='Z Material Top')
      self.st4.grid(row=15, column=1)
      self.MaterialTopVar = tk.StringVar()
      self.MaterialTopE = tk.Entry(self, width=10, textvariable=self.MaterialTopVar)
      self.MaterialTopE.grid(row=16, column=1)
      self.MaterialTopVar.set('0.000')
      self.MaterialTopE.bind("<Return>", self.TabToNext)
      self.MaterialTopE.bind("<KP_Enter>", self.TabToNext)

      self.st5 = tk.Label(self, text='Z Start Height')
      self.st5.grid(row=15, column=2)
      self.StartHeightVar = tk.StringVar()
      self.StartHeightE = tk.Entry(self, width=10, textvariable=self.StartHeightVar)
      self.StartHeightE.grid(row=16, column=2)
      self.StartHeightVar.set('0.1000')
      self.StartHeightE.bind("<Return>", self.TabToNext)
      self.StartHeightE.bind("<KP_Enter>", self.TabToNext)

      self.st21 = tk.Label(self, text='Drill Cycle')
      self.st21.grid(row=1, column=3)
      self.DrillCycle=[('G81',1),('G83 (Peck)', 2)]
      self.DrillCycleVar = tk.IntVar()
      for text, value in self.DrillCycle:
          self.rb4=tk.Radiobutton(self, text=text, value=value, variable=self.DrillCycleVar)
          self.rb4.grid(column=3,row=value+1, sticky=tk.W)
      self.DrillCycleVar.set(1)

      self.st19 = tk.Label(self, text='Drill Tool #')
      self.st19.grid(row=4, column=3)
      self.DrillToolVar = tk.StringVar()
      self.DrillToolE = tk.Entry(self, width=10, textvariable=self.DrillToolVar)
      self.DrillToolE.grid(row=5, column=3)
      self.DrillToolE.bind("<Return>", self.TabToNext)
      self.DrillToolE.bind("<KP_Enter>", self.TabToNext)
      self.DrillToolVar.set('1')

      self.st7 = tk.Label(self, text='Drill RPM')
      self.st7.grid(row=6, column=3)
      self.DrillRPMVar = tk.StringVar()
      self.DrillRPME = tk.Entry(self, width=10, textvariable=self.DrillRPMVar)
      self.DrillRPME.grid(row=7, column=3)
      self.DrillRPME.bind("<Return>", self.TabToNext)
      self.DrillRPME.bind("<KP_Enter>", self.TabToNext)
      self.DrillRPMVar.set('1800')

      self.st8 = tk.Label(self, text='Drill Feed')
      self.st8.grid(row=8, column=3)
      self.DrillFeedVar = tk.StringVar()
      self.DrillFeedE = tk.Entry(self, width=10, textvariable=self.DrillFeedVar)
      self.DrillFeedE.grid(row=9, column=3)
      self.DrillFeedVar.set('10.0')
      self.DrillFeedE.bind("<Return>", self.TabToNext)
      self.DrillFeedE.bind("<KP_Enter>", self.TabToNext)

      self.st9 = tk.Label(self, text='Drill Depth')
      self.st9.grid(row=10, column=3)
      self.DrillDepthVar = tk.StringVar()
      self.DrillDepthE = tk.Entry(self, width=10, textvariable=self.DrillDepthVar)
      self.DrillDepthE.grid(row=11, column=3)
      self.DrillDepthE.bind("<Return>", self.TabToNext)
      self.DrillDepthE.bind("<KP_Enter>", self.TabToNext)
      self.DrillDepthVar.set('-0.500')

      self.st22 = tk.Label(self, text='Peck Depth')
      self.st22.grid(row=12, column=3)
      self.PeckDepthVar = tk.StringVar()
      self.PeckDepthE = tk.Entry(self, width=10, textvariable=self.PeckDepthVar)
      self.PeckDepthE.grid(row=13, column=3)
      self.PeckDepthE.bind("<Return>", self.TabToNext)
      self.PeckDepthE.bind("<KP_Enter>", self.TabToNext)
      self.PeckDepthVar.set('0.125')

      self.st20 = tk.Label(self, text='Tap Tool #')
      self.st20.grid(row=14, column=3)
      self.TapToolVar = tk.StringVar()
      self.TapToolVarE = tk.Entry(self, width=10, textvariable=self.TapToolVar)
      self.TapToolVarE.grid(row=15, column=3)
      self.TapToolVarE.bind("<Return>", self.TabToNext)
      self.TapToolVarE.bind("<KP_Enter>", self.TabToNext)
      self.TapToolVar.set('2')

      self.st10 = tk.Label(self, text='Tap RPM')
      self.st10.grid(row=16, column=3)
      self.TapRPMVar = tk.StringVar()
      self.TapRPME = tk.Entry(self, width=10, textvariable=self.TapRPMVar)
      self.TapRPME.grid(row=17, column=3)
      self.TapRPME.bind("<Return>", self.TabToNext)
      self.TapRPME.bind("<KP_Enter>", self.TabToNext)
      self.TapRPMVar.set('300')

      self.st11 = tk.Label(self, text='Tap Depth')
      self.st11.grid(row=18, column=3)
      self.TapDepthVar = tk.StringVar()
      self.TapDepthE = tk.Entry(self, width=10, textvariable=self.TapDepthVar)
      self.TapDepthE.grid(row=19, column=3)
      self.TapDepthE.bind("<Return>", self.TabToNext)
      self.TapDepthE.bind("<KP_Enter>", self.TabToNext)
      self.TapDepthVar.set('-0.250')

      self.InsertEOFVar = tk.IntVar()
      self.InsertEOF = tk.Checkbutton(self, text='Insert EOF', 
          variable=self.InsertEOFVar, width=10)
      self.InsertEOF.grid(row=20, column=3, rowspan=2)
      self.InsertEOF.toggle()
      self.InsertEOF.bind("<Return>", self.TabToNext)
      self.InsertEOF.bind("<KP_Enter>", self.TabToNext)

      self.st12 = tk.Label(self, text='X Center')
      self.st12.grid(row=1, column=4, sticky=tk.W)
      self.XCenterVar = tk.StringVar()
      self.XCenterE = tk.Entry(self, width=10, textvariable=self.XCenterVar)
      self.XCenterE.grid(row=2, column=4, sticky=tk.W)
      self.XCenterE.bind("<Return>", self.MoveToY)
      self.XCenterE.bind("<KP_Enter>", self.MoveToY)

      self.st13 = tk.Label(self, text='Y Center')
      self.st13.grid(row=1, column=4, sticky=tk.E)
      self.YCenterVar = tk.StringVar()
      self.YCenterE = tk.Entry(self, width=10, textvariable=self.YCenterVar)
      self.YCenterE.grid(row=2, column=4, sticky=tk.E)
      self.YCenterE.bind("<Return>", self.AddToList)
      self.YCenterE.bind("<KP_Enter>", self.AddToList)

      self.ThreadDepth=[('75% Thread',1),('50% Thread',2)]
      self.ThreadDepthVar = tk.IntVar()
      for text, value in self.ThreadDepth:
          self.rb5=tk.Radiobutton(self, text=text, value=value, variable=self.ThreadDepthVar)
          self.rb5.grid(column=2,row=value+10, sticky=tk.W)
          self.rb5.bind("<ButtonRelease-1>", self.rb5event)
      self.ThreadDepthVar.set(1)


      self.st15 = tk.Label(self, text='X & Y List')
      self.st15.grid(row=3, column=4)
      self.CordList = tk.Listbox(self, height=20)
      self.CordList.grid(row=4, column=4, rowspan=17, sticky=tk.E+tk.W+tk.N+tk.S)
      self.CordList.bind("<Double-Button-1>", self.EditListItem)
      self.CordList.bind("<ButtonRelease-1>", self.MouseSelect)
      self.CordList.bind("<Delete>", self.RemoveFromList)
      self.ListIndex = ''
      self.CLScroll = tk.Scrollbar(self,command = self.CordList.yview)
      self.CLScroll.grid(row=4, column=5, rowspan=17, sticky=tk.N+tk.S+tk.W)
      self.CordList.configure(yscrollcommand = self.CLScroll.set) 

      self.st16 = tk.Label(self, text='G-Code')
      self.st16.grid(row=1, column=6)
      self.g_code = tk.Text(self,width=50,height=25,bd=2)
      self.g_code.grid(row=2, column=6, rowspan=20, sticky=tk.E+tk.W+tk.N+tk.S)
      self.Gscroll = tk.Scrollbar(self,command = self.g_code.yview)
      self.Gscroll.grid(row=2, column=7, rowspan=20, sticky=tk.N+tk.S+tk.W)
      self.g_code.configure(yscrollcommand = self.Gscroll.set) 

      self.st17 = tk.Label(self, text='Units')
      self.st17.grid(row=17, column=0)
      self.Units=[('Inch',1),('Metric', 2)]
      self.UnitsVar = tk.IntVar()
      for text, value in self.Units:
          self.rb4=tk.Radiobutton(self, text=text, value=value, variable=self.UnitsVar)
          self.rb4.grid(column=0,row=value+17, sticky=tk.W)
          self.rb4.bind("<ButtonRelease-1>", self.UnitsWarning)
      self.UnitsVar.set(1)

      self.st14 = tk.Label(self, text='Operations')
      self.st14.grid(row=17, column=1)
      self.Operations=[('Drill & Tap',1),('Drill Only',2),('Tap Only',3)]
      self.OperationsVar = tk.IntVar()
      for text, value in self.Operations:
          self.rb4=tk.Radiobutton(self, text=text, value=value, variable=self.OperationsVar)
          self.rb4.grid(column=1,row=value+17, sticky=tk.W)
      self.OperationsVar.set(1)

      self.st18 = tk.Label(self, text='Coolant')
      self.st18.grid(row=17, column=2)
      self.Coolant=[(' None',1),('Flood', 2),(' Mist', 3)]
      self.CoolantVar = tk.IntVar()
      for text, value in self.Coolant:
          self.rb5=tk.Radiobutton(self, text=text, value=value, variable=self.CoolantVar)
          self.rb5.grid(column=2,row=value+17)
      self.CoolantVar.set(1)

      self.GenerateBtn = tk.Button(self, text="Generate", command=self.GeneratePath, width=7)
      self.GenerateBtn.grid(row=22, column=3)

      if IN_AXIS:
          self.WriteButton = tk.Button(self, text='To AXIS',\
              command=self.WriteToAxis)
      else:
          self.WriteButton = tk.Button(self, text='To Clipboard',
              command=self.CopyClipboard, width=7)
      self.WriteButton.grid(row=22, column=4)

      self.ClearGCode = tk.Button(self, text='Clear G Code Window', command=self.ClearGCode)
      self.ClearGCode.grid(row=22,column=6, sticky=tk.W)
      
      self.quitButton = tk.Button(self, text="Cancel", command=self.quit, width=7)
      self.quitButton.grid(row=22, column=6, sticky=tk.E)

      # Inch Drills
      # tap size, pitch, 75% drill, 75% drill diameter, 50% drill for steel, 50% dia
      self.NF_TapI = {1:'#6-40,0.02500,#33,0.113,#31,0.120',
                    2:'#8-36,0.02778,#29,0.136,#26,0.147',
                    3:'#10-32,0.03125,#21,0.159,#18,0.169',
                    4:'#12-28,0.03571,#14,0.182,#10,0.1935',
                    5:'1/4-28,0.03571,#3,0.213,#1,0.228',
                    6:'5/16-24,0.04167,I,0.272,9/32,0.2812',
                    7:'3/8-24,0.4167,Q,0.332,S,0.348',
                    8:'7/16-20,0.0500,25/64,0.3906,13/32,0.4062',
                    9:'1/2-20,0.5000,29/64,0.4531,15/32,0.4688',
                   10:'9/16-18,0.5556,33/64,0.5156,17/32,0.5312',
                   11:'5/8-18,0.5556,37/64,0.5781,19/32,0.5938'}
      self.NC_TapI = {1:'#6-32,0.03125,#36,0.1065,#32,0.116',
                    2:'#8-32,0.03125,#29,0.136,#27,0.144',
                    3:'#10-24,0.04167,#25,0.1495,#20,0.161',
                    4:'#12-24,0.04167,#16,0.177,#12,0.189',
                    5:'1/4-20,0.05000,#7,0.201,7/32,0.2188',
                    6:'5/16-18,0.05556,F,0.257,J,0.277',
                    7:'3/8-16,0.06250,5/16,0.3125,Q,0.332',
                    8:'7/16-14,0.07143,U,0.368,25/64,0.3906',
                    9:'1/2-13,0.07692,27/64,0.4219,29/64,0.4531',
                   10:'9/16-12,0.08333,31/64,0.4844,33/64,0.5156',
                   11:'5/8-11,0.09091,17/32,0.5312,9/16,0.5625'}
      self.M_TapI = {1:'M3-0.5,0.01969,#39,0.0995,#36,0.1065',
                    2:'M4-0.7,0.02756,#30,0.1285,#28,0.1405',
                    3:'M5-0.8,0.03150,#19,0.166,#16,0.177',
                    4:'M6-1.0,0.03937,#8,0.199,#4,0.209',
                    5:'M8-1.25,0.04921,H,0.266,J,0.277',
                    6:'M10-1.5,0.05906,R,0.339,T,0.358',
                    7:'M12-1.75,0.06890,13/32,0.4062,27/64,0.4219',
                    8:'M14-2.0,0.07874,15/32,0.4688,1/2,0.500',
                    9:'M16-2.0,0.07874,35/64,0.5469,37/64,0.5781'}

      # Metric Drills change inch drills to metric and your set
      # tap size, pitch, 75% drill, 75% drill diameter, 50% drill for steel, 50% dia
      self.NF_TapM = {1:'#6-40,0.6350,M2.9,2.9,M3,3.0',
                    2:'#8-36,0.02778,#29,0.136,#26,0.147',
                    3:'#10-32,0.03125,#21,0.159,#18,0.169',
                    4:'#12-28,0.03571,#14,0.182,#10,0.1935',
                    5:'1/4-28,0.03571,#3,0.213,#1,0.228',
                    6:'5/16-24,0.04167,I,0.272,9/32,0.2812',
                    7:'3/8-24,0.4167,Q,0.332,S,0.348',
                    8:'7/16-20,0.0500,25/64,0.3906,13/32,0.4062',
                    9:'1/2-20,0.5000,29/64,0.4531,15/32,0.4688',
                   10:'9/16-18,0.5556,33/64,0.5156,17/32,0.5312',
                   11:'5/8-18,0.5556,37/64,0.5781,19/32,0.5938'}
      self.NC_TapM = {1:'#6-32,0.7937,M2.7,2.7,M2.9,2.9',
                    2:'#8-32,0.03125,#29,0.136,#27,0.144',
                    3:'#10-24,0.04167,#25,0.1495,#20,0.161',
                    4:'#12-24,0.04167,#16,0.177,#12,0.189',
                    5:'1/4-20,0.05000,#7,0.201,7/32,0.2188',
                    6:'5/16-18,0.05556,F,0.257,J,0.277',
                    7:'3/8-16,0.06250,5/16,0.3125,Q,0.332',
                    8:'7/16-14,0.07143,U,0.368,25/64,0.3906',
                    9:'1/2-13,0.07692,27/64,0.4219,29/64,0.4531',
                   10:'9/16-12,0.08333,31/64,0.4844,33/64,0.5156',
                   11:'5/8-11,0.09091,17/32,0.5312,9/16,0.5625'}
      self.M_TapM = {1:'M3-0.5,0.5000,M2.5,2.5,M2.7,2.7',
                    2:'M4-0.7,0.02756,#30,0.1285,#28,0.1405',
                    3:'M5-0.8,0.03150,#19,0.166,#16,0.177',
                    4:'M6-1.0,0.03937,#8,0.199,#4,0.209',
                    5:'M8-1.25,0.04921,H,0.266,J,0.277',
                    6:'M10-1.5,0.05906,R,0.339,T,0.358',
                    7:'M12-1.75,0.06890,13/32,0.4062,27/64,0.4219',
                    8:'M14-2.0,0.07874,15/32,0.4688,1/2,0.500',
                    9:'M16-2.0,0.07874,35/64,0.5469,37/64,0.5781'}

      self.ThreadPitch = 0

  def UnitsWarning(self,var):
    tkMessageBox.showwarning('Metric Units', 'The Metric Dictionary is still in Inch.\n Do not use!')
    self.UnitsVar.set(1)

  def rb1event(self,var):
    if self.UnitsVar.get() == 1:
      self.nf = self.NF_TapI[self.var1.get()]
    if self.UnitsVar.get() == 2:
      self.nf = self.NF_TapM[self.var1.get()]
    self.nfsp = self.nf.split(',')
    self.TapSizeVar.set(self.nfsp[0])
    if self.ThreadDepthVar.get() == 1:
      self.TapDrill.set(self.nfsp[2])
      self.HoleDepthVar.set(self.nfsp[3])
    else:
      self.TapDrill.set(self.nfsp[4])
      self.HoleDepthVar.set(self.nfsp[5])
    self.var2.set(0)
    self.var3.set(0)

  def rb2event(self,var):
    if self.UnitsVar.get() == 1:
      self.nc = self.NC_TapI[self.var2.get()]
    if self.UnitsVar.get() == 2:
      self.nc = self.NC_TapM[self.var2.get()]
    self.ncsp = self.nc.split(',')
    self.TapSizeVar.set(self.ncsp[0])
    if self.ThreadDepthVar.get() == 1:
      self.TapDrill.set(self.ncsp[2])
      self.HoleDepthVar.set(self.ncsp[3])
    else:
      self.TapDrill.set(self.ncsp[4])
      self.HoleDepthVar.set(self.ncsp[5])
    self.var1.set(0)
    self.var3.set(0)

  def rb3event(self,var):
    if self.UnitsVar.get() == 1:
      self.ms = self.M_TapI[self.var3.get()]
    if self.UnitsVar.get() == 2:
      self.ms = self.M_TapM[self.var3.get()]
    self.mssp = self.ms.split(',')
    self.TapSizeVar.set(self.mssp[0])
    if self.ThreadDepthVar.get() == 1:
      self.TapDrill.set(self.mssp[2])
      self.HoleDepthVar.set(self.mssp[3])
    else:
      self.TapDrill.set(self.mssp[4])
      self.HoleDepthVar.set(self.mssp[5])
    self.var1.set(0)
    self.var2.set(0)

  def rb5event(self,var):
    if self.var1.get() > 0:
      self.rb1event(self.var1)
    if self.var2.get() > 0:
      self.rb2event(self.var2)
    if self.var3.get() > 0:
      self.rb3event(self.var3)

  def GeneratePath(self):

    # Gather the information from the form
    if self.CoolantVar.get() == 1:self.Coolant = '9'
    if self.CoolantVar.get() == 2:self.Coolant = '7'
    if self.CoolantVar.get() == 3:self.Coolant = '8'

    if self.ClearHeightVar.get() == '':
      tkMessageBox.showwarning('Entry Missing', 'Please enter the Clearance Height!')
      return
    self.ClearHeight = float(self.ClearHeightVar.get())
    if self.MaterialTopVar.get() == '':
      tkMessageBox.showwarning('Entry Missing', 'Please enter the Z Top of Material!')
      return
    self.MaterialTop = float(self.MaterialTopVar.get())
    if self.StartHeightVar.get() == '':
      tkMessageBox.showwarning('Entry Missing', 'Please enter the Z Start Height!')
      return
    self.StartHeight = float(self.StartHeightVar.get())
    if self.CordList.size() == 0:
      tkMessageBox.showwarning('Entry Missing', 'Please enter at least one XY Location!')
      return

    if self.OperationsVar.get() <> 3: # Drilling info needed
      if self.DrillToolVar.get() == '':
        tkMessageBox.showwarning('Entry Missing', 'Please enter the Drill Tool #!')
        return
      self.DrillTool = self.DrillToolVar.get()
      if self.DrillRPMVar.get() == '':
        tkMessageBox.showwarning('Entry Missing', 'Please enter the Drilling RPM!')
        return
      self.DrillRPM = self.DrillRPMVar.get()
      if self.DrillFeedVar.get() == '':
        tkMessageBox.showwarning('Entry Missing', 'Please enter the Drilling Feed!')
        return
      self.DrillFeed = self.DrillFeedVar.get()
      if self.DrillDepthVar.get() == '':
        tkMessageBox.showwarning('Entry Missing', 'Please enter the Drill Depth!')
        return
      self.DrillDepth = float(self.DrillDepthVar.get())
      if self.DrillCycleVar.get() == 2:
        if self.PeckDepthVar.get() == '':
          tkMessageBox.showwarning('Entry Missing', 'Please enter the Peck Depth!')
        return
      self.PeckDepth = float(self.PeckDepthVar.get())

    if self.OperationsVar.get() <> 2: # Tapping info needed
      if self.var1.get() + self.var2.get() + self.var3.get() == 0:
        tkMessageBox.showwarning('Entry Missing', 'Please select a tap size!')
        return
      if self.UnitsVar.get() == 1:
        if self.var1.get() > 0: self.TapInfo = self.NF_TapI[self.var1.get()]
        if self.var2.get() > 0: self.TapInfo = self.NC_TapI[self.var2.get()]
        if self.var3.get() > 0: self.TapInfo = self.M_TapI[self.var3.get()]
      if self.UnitsVar.get() == 2:
        if self.var1.get() > 0: self.TapInfo = self.NF_TapM[self.var1.get()]
        if self.var2.get() > 0: self.TapInfo = self.NC_TapM[self.var2.get()]
        if self.var3.get() > 0: self.TapInfo = self.M_TapM[self.var3.get()]
      self.TapInfoSplit = self.TapInfo.split(',')
      self.ThreadPitch = float(self.TapInfoSplit[1])
      if self.TapToolVar.get() == '':
        tkMessageBox.showwarning('Entry Missing', 'Please enter a tap Tool #!')
        return
      self.TapTool = self.TapToolVar.get()
      if self.TapRPMVar.get() == '':
        tkMessageBox.showwarning('Entry Missing', 'Please enter a tap RPM!')
        return
      self.TapRPM = self.TapRPMVar.get()
      if self.TapDepthVar.get() == '':
        tkMessageBox.showwarning('Entry Missing', 'Please enter a tap depth!')
        return
      self.TapDepth = float(self.TapDepthVar.get())

    # Generate G code
    self.g_code.delete(1.0,tk.END)
    if self.OperationsVar.get() <> 3:
      self.g_code.insert(tk.END,';Drill Tool T%s, Size %s\n' % (self.DrillToolVar.get(),self.TapDrill.get()))
    if self.OperationsVar.get() <> 2:
      self.g_code.insert(tk.END,';Tap Tool T%s, Size %s\n' % (self.TapToolVar.get(),self.TapSizeVar.get()))
    if self.UnitsVar.get() == 1: self.preamble = 'G20 G17 G40 G49 G64 P0.005 G80 G90 G94\n'
    if self.UnitsVar.get() == 2: self.preamble = 'G21 G17 G40 G49 G64 P0.005 G80 G90 G94\n'
    self.g_code.insert(tk.END, self.preamble)

    if self.OperationsVar.get() <> 3: # Drilling Required
      self.g_code.insert(tk.END, 'T%s M6 G43\n' %(self.DrillTool))
      self.g_code.insert(tk.END, 'M3 S%s M%s F%s\n' %(self.DrillRPM, self.Coolant, self.DrillFeed))

      for n in range(0,int(self.CordList.size())):
        self.Items = self.CordList.get(0,tk.END)
        self.SplitUp = self.Items[n].split()
        self.XCenter = float(self.SplitUp[0].lstrip('XY'))
        self.YCenter = float(self.SplitUp[1].lstrip('XY'))
        if n == 0:
          if self.DrillCycleVar.get() == 1:
            self.g_code.insert(tk.END,'G81 X%.4f Y%.4f Z%.4f R%.4f\n' \
            %(self.XCenter, self.YCenter, self.DrillDepth, self.ClearHeight))
          if self.DrillCycleVar.get() == 2:
            self.g_code.insert(tk.END,'G83 X%.4f Y%.4f Z%.4f R%.4f Q%.4f\n' \
            %(self.XCenter, self.YCenter, self.DrillDepth, self.ClearHeight, self.PeckDepth))
        if n > 0:
          self.g_code.insert(tk.END, 'X%.4f Y%.4f\n' %(self.XCenter, self.YCenter))

      self.g_code.insert(tk.END, 'G80\n')
      self.g_code.insert(tk.END, 'M5')
      if self.CoolantVar.get() <> 1:self.g_code.insert(tk.END, 'M9\n')

    if self.OperationsVar.get() <> 2: # Tapping Required

      self.g_code.insert(tk.END, 'T%s M6 G43\n' %(self.TapTool))
      self.g_code.insert(tk.END, 'M3 S%s M%s\n' %(self.TapRPM, self.Coolant))

      for n in range(0,int(self.CordList.size())):
        self.Items = self.CordList.get(0,tk.END)
        self.SplitUp = self.Items[n].split()
        self.XCenter = float(self.SplitUp[0].lstrip('XY'))
        self.YCenter = float(self.SplitUp[1].lstrip('XY'))
        self.g_code.insert(tk.END, 'G0 X%.4f Y%.4f Z%.4f\n' %(self.XCenter, self.YCenter, self.ClearHeight))
        if self.ClearHeight > self.StartHeight: self.g_code.insert(tk.END, 'Z%.4f\n' %(self.StartHeight))
        self.g_code.insert(tk.END, 'G33.1 Z%.4f K%.5f\n' %(self.TapDepth, self.ThreadPitch))
        if self.ClearHeight > self.StartHeight: self.g_code.insert(tk.END, 'G0 Z%.4f\n' %(self.ClearHeight))

    if self.InsertEOFVar.get() == 1:
        self.g_code.insert(tk.END, 'M2\n')

  def WriteToAxis(self):
      sys.stdout.write(self.g_code.get(0.0, tk.END))
      self.quit()

  def CopyClipboard(self):
      self.g_code.clipboard_clear()
      self.g_code.clipboard_append(self.g_code.get(0.0, tk.END))

  def ClearGCode(self):
      self.g_code.delete(1.0,tk.END)

  def TabToNext(self,event):
      #def return_pressed(event):
      event.widget.event_generate('<Tab>')
      return 'break'

  def MoveToY(self,var):
      self.YCenterE.focus_set()

  def AddToList(self,var):
      if len(self.XCenterE.get()) > 0 and len(self.YCenterE.get()) > 0:
          self.InsertString = 'X%.4f Y%.4f' \
              %(float(self.XCenterE.get()), float(self.YCenterE.get()))
          if len(self.ListIndex) > 0:
              self.CordList.delete(int(self.ListIndex))
              self.CordList.insert(int(self.ListIndex), self.InsertString)
              self.ListIndex = ''
          else:
              self.CordList.insert(tk.END, self.InsertString)
          self.XCenterVar.set('')
          self.YCenterVar.set('')
      self.XCenterE.focus_set()

  def EditListItem(self,var):
      self.ListIndex = self.CordList.curselection()[0]
      self.seltext = []
      self.seltext = self.CordList.get(self.ListIndex).split()
      self.Xtext = self.seltext[0]
      self.Ytext = self.seltext[1]
      self.XCenterVar.set(self.Xtext[1:])
      self.YCenterVar.set(self.Ytext[1:])
      self.XCenterE.focus_set()         

  def RemoveFromList(self,var):
      self.ListIndex = self.CordList.curselection()[0]
      self.CordList.delete(int(self.ListIndex))
      self.ListIndex = ''

  def MouseSelect(self, var):
      self.CordList.focus_set()

  def HelpInfo(self,var=''):
      c1 = tk.Toplevel(app)
      c1.transient(app)
      canvas = tk.Canvas(c1, width = 600,  height = 375)
      canvas.create_text( 10, 10, anchor=tk.NW, 
        text= "This Program creates the G code for Rigid\n"
              "Tapping for LinuxCNC. If you open tap.py\n"
              "from Axis the G code will be sent to Axis.\n"
              "Otherwise the generated G code can be\n"
              "copied to the clipboard\n"
              "To enter coordinates in the list use the\n"
              "Enter key.\n\n"
              "To Edit an item in the X & Y List double\n"
              "click on it. Then edit it and press Enter\n"
              "to put it back in the list\n\n"
              "To Delete an item in the X & Y List click on\n"
              "it and press the delete key.\n\n"
              "The Enter key will advance you to the next\n"
              "field.")
      canvas.create_text( 310, 10, anchor=tk.NW, 
        text= "Minimum entry's depend on Options selected.\n\n"
              "Some effort has been made to reject\n"
              "senseless input.\n\n"
              "Please check the output with a backplotter\n"
              "such as Axis\n\n"
              "To use this software in Axis, open tap.py \n"
              "from the File > Open in Axis. tap.py will\n"
              "know and send the output to Axis when done.\n"
              "Make sure Axis is setup for .py extensions")
      canvas.grid()

  def HelpAbout(self,var=''):
    self.message = 'Programmed by JT\n Version %s \n Use at your own risk!' % Version
    tkMessageBox.showinfo('Help About', self.message)

app = Application()
app.master.title("Rigid Tap %s" %(Version))
app.mainloop()

